
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on
`Keep a Changelog`_.

Starting with version 0.12.0, this project implements a version of
`Semantic Versioning`_ described
`here <https://iscinumpy.dev/post/bound-version-constraints/#semver>`_ called
"Realistic" Semantic Versioning.

`Unreleased`_
--------------

* First version.

.. _Unreleased: https://github.com/ugognw/pchemdb/

.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html
